==> vue-icon-saas-3.8.0.tgz: package/lib/font-weight.js <==
import { svg } from "@xmweb-ui/vue-common";
import { openBlock, createElementBlock, createElementVNode } from "vue";
var _hoisted_1 = {
  viewBox: "0 0 30 17",
  xmlns: "http://www.w3.org/2000/svg"
};
var _hoisted_2 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M10.296 10.288H4.944l-1.536 3.864c-.08.192-.12.352-.12.48 0 .336.488.576 1.464.72.112.016.188.06.228.132a.51.51 0 0 1 .06.252c0 .096-.016.224-.048.384-.432-.032-.888-.06-1.368-.084-.48-.024-.952-.036-1.416-.036-.32 0-.648.008-.984.024-.336.016-.688.048-1.056.096a1.578 1.578 0 0 1-.048-.384c0-.112.02-.208.06-.288.04-.08.124-.128.252-.144.496-.08.868-.18 1.116-.3.248-.12.428-.308.54-.564L7.872.52c.112-.272.264-.408.456-.408.064 0 .16.016.288.048l5.808 14.352c.096.224.312.4.648.528s.664.216.984.264a.572.572 0 0 1 .228.132c.056.056.084.156.084.3 0 .096-.016.224-.048.384-.512-.032-1.016-.06-1.512-.084a28.904 28.904 0 0 0-2.928 0c-.576.024-1.096.052-1.56.084a2.065 2.065 0 0 1-.048-.384c0-.144.028-.244.084-.3.056-.056.108-.084.156-.084.416-.08.752-.172 1.008-.276.256-.104.384-.26.384-.468a.93.93 0 0 0-.096-.36l-1.512-3.96Zm-.384-.984L7.68 3.424l-2.328 5.88h4.56Z",
    opacity: ".7"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_3 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M16.296 10.288h-5.352l-1.536 3.864c-.08.192-.12.352-.12.48 0 .336.488.576 1.464.72.112.016.188.06.228.132a.51.51 0 0 1 .06.252c0 .096-.016.224-.048.384-.432-.032-.888-.06-1.368-.084-.48-.024-.952-.036-1.416-.036-.32 0-.648.008-.984.024-.336.016-.688.048-1.056.096a1.578 1.578 0 0 1-.048-.384c0-.112.02-.208.06-.288.04-.08.124-.128.252-.144.496-.08.868-.18 1.116-.3.248-.12.428-.308.54-.564L13.872.52c.112-.272.264-.408.456-.408.064 0 .16.016.288.048l5.808 14.352c.096.224.312.4.648.528s.664.216.984.264a.572.572 0 0 1 .228.132c.056.056.084.156.084.3 0 .096-.016.224-.048.384-.512-.032-1.016-.06-1.512-.084a28.904 28.904 0 0 0-2.928 0c-.576.024-1.096.052-1.56.084a2.065 2.065 0 0 1-.048-.384c0-.144.028-.244.084-.3.056-.056.108-.084.156-.084.416-.08.752-.172 1.008-.276.256-.104.384-.26.384-.468a.93.93 0 0 0-.096-.36l-1.512-3.96Zm-.384-.984-2.232-5.88-2.328 5.88h4.56Z",
    opacity: ".9"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_4 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M22.96 10.72h-5.04l-1.248 3.336a.747.747 0 0 0-.096.264 1.444 1.444 0 0 0-.024.216c0 .176.084.32.252.432.168.112.508.208 1.02.288.224.032.336.184.336.456 0 .112-.016.248-.048.408-.432-.032-.888-.06-1.368-.084-.48-.024-.952-.036-1.416-.036a18.236 18.236 0 0 0-2.184.12.476.476 0 0 1-.048-.216v-.192c0-.304.104-.464.312-.48.496-.096.852-.2 1.068-.312.216-.112.388-.304.516-.576L20.776.52c.128-.272.32-.408.576-.408.08 0 .16.004.24.012.08.008.168.02.264.036l5.784 14.256c.096.24.28.42.552.54.272.12.568.204.888.252.24.048.36.208.36.48 0 .128-.016.272-.048.432-.512-.032-1.016-.06-1.512-.084a28.904 28.904 0 0 0-2.208-.024c-.32.008-.648.02-.984.036-.336.016-.668.028-.996.036-.328.008-.604.02-.828.036a.476.476 0 0 1-.048-.216v-.192c0-.144.028-.252.084-.324a.34.34 0 0 1 .18-.132c.416-.08.724-.172.924-.276.2-.104.3-.26.3-.468 0-.096-.024-.216-.072-.36L22.96 10.72Zm-.456-1.2-2.04-5.4-2.088 5.4h4.128Z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_5 = [_hoisted_2, _hoisted_3, _hoisted_4];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("svg", _hoisted_1, _hoisted_5);
}
var FontWeight = {
  render
};
var IconFontWeight = svg({
  name: "IconFontWeight",
  component: FontWeight
});
export {
  IconFontWeight as default
};

==> vue-icon-saas-3.22.1.tgz: package/lib/font-weight.js <==
import { svg } from "@opentinyvue/vue-common";
import { createElementBlock, openBlock, createElementVNode } from "vue";
var _hoisted_1 = {
  viewBox: "0 0 30 17",
  xmlns: "http://www.w3.org/2000/svg"
};
var _hoisted_2 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M10.296 10.288H4.944l-1.536 3.864c-.08.192-.12.352-.12.48 0 .336.488.576 1.464.72.112.016.188.06.228.132a.51.51 0 0 1 .06.252c0 .096-.016.224-.048.384-.432-.032-.888-.06-1.368-.084-.48-.024-.952-.036-1.416-.036-.32 0-.648.008-.984.024-.336.016-.688.048-1.056.096a1.578 1.578 0 0 1-.048-.384c0-.112.02-.208.06-.288.04-.08.124-.128.252-.144.496-.08.868-.18 1.116-.3.248-.12.428-.308.54-.564L7.872.52c.112-.272.264-.408.456-.408.064 0 .16.016.288.048l5.808 14.352c.096.224.312.4.648.528s.664.216.984.264a.572.572 0 0 1 .228.132c.056.056.084.156.084.3 0 .096-.016.224-.048.384-.512-.032-1.016-.06-1.512-.084a28.904 28.904 0 0 0-2.928 0c-.576.024-1.096.052-1.56.084a2.065 2.065 0 0 1-.048-.384c0-.144.028-.244.084-.3.056-.056.108-.084.156-.084.416-.08.752-.172 1.008-.276.256-.104.384-.26.384-.468a.93.93 0 0 0-.096-.36l-1.512-3.96Zm-.384-.984L7.68 3.424l-2.328 5.88h4.56Z",
    opacity: ".7"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_3 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M16.296 10.288h-5.352l-1.536 3.864c-.08.192-.12.352-.12.48 0 .336.488.576 1.464.72.112.016.188.06.228.132a.51.51 0 0 1 .06.252c0 .096-.016.224-.048.384-.432-.032-.888-.06-1.368-.084-.48-.024-.952-.036-1.416-.036-.32 0-.648.008-.984.024-.336.016-.688.048-1.056.096a1.578 1.578 0 0 1-.048-.384c0-.112.02-.208.06-.288.04-.08.124-.128.252-.144.496-.08.868-.18 1.116-.3.248-.12.428-.308.54-.564L13.872.52c.112-.272.264-.408.456-.408.064 0 .16.016.288.048l5.808 14.352c.096.224.312.4.648.528s.664.216.984.264a.572.572 0 0 1 .228.132c.056.056.084.156.084.3 0 .096-.016.224-.048.384-.512-.032-1.016-.06-1.512-.084a28.904 28.904 0 0 0-2.928 0c-.576.024-1.096.052-1.56.084a2.065 2.065 0 0 1-.048-.384c0-.144.028-.244.084-.3.056-.056.108-.084.156-.084.416-.08.752-.172 1.008-.276.256-.104.384-.26.384-.468a.93.93 0 0 0-.096-.36l-1.512-3.96Zm-.384-.984-2.232-5.88-2.328 5.88h4.56Z",
    opacity: ".9"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_4 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M22.96 10.72h-5.04l-1.248 3.336a.747.747 0 0 0-.096.264 1.444 1.444 0 0 0-.024.216c0 .176.084.32.252.432.168.112.508.208 1.02.288.224.032.336.184.336.456 0 .112-.016.248-.048.408-.432-.032-.888-.06-1.368-.084-.48-.024-.952-.036-1.416-.036a18.236 18.236 0 0 0-2.184.12.476.476 0 0 1-.048-.216v-.192c0-.304.104-.464.312-.48.496-.096.852-.2 1.068-.312.216-.112.388-.304.516-.576L20.776.52c.128-.272.32-.408.576-.408.08 0 .16.004.24.012.08.008.168.02.264.036l5.784 14.256c.096.24.28.42.552.54.272.12.568.204.888.252.24.048.36.208.36.48 0 .128-.016.272-.048.432-.512-.032-1.016-.06-1.512-.084a28.904 28.904 0 0 0-2.208-.024c-.32.008-.648.02-.984.036-.336.016-.668.028-.996.036-.328.008-.604.02-.828.036a.476.476 0 0 1-.048-.216v-.192c0-.144.028-.252.084-.324a.34.34 0 0 1 .18-.132c.416-.08.724-.172.924-.276.2-.104.3-.26.3-.468 0-.096-.024-.216-.072-.36L22.96 10.72Zm-.456-1.2-2.04-5.4-2.088 5.4h4.128Z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_5 = [_hoisted_2, _hoisted_3, _hoisted_4];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("svg", _hoisted_1, [].concat(_hoisted_5));
}
var FontWeight = {
  render
};
var index = function index2() {
  return svg({
    name: "IconFontWeight",
    component: FontWeight
  })();
};
export {
  index as default
};
